from menten_gcn import DataMaker
import menten_gcn.decorators as decs

import numpy as np


class Maguire_Grattarola_2021(DataMaker):
    def __init__(self):
        decorators = [decs.Sequence(), decs.CACA_dist(), decs.PhiPsiRadians(),
                      decs.ChiAngleDecorator(), decs.trRosettaEdges(),
                      decs.SequenceSeparation(), decs.RosettaJumpDecorator(rottype="euler"),
                      decs.RosettaHBondDecorator(),
                      decs.AbbreviatedRef2015Decorator_v0()]
        DataMaker.__init__(self, decorators=decorators,
                           edge_distance_cutoff_A=15.0,
                           max_residues=30,
                           exclude_bbdec=False,
                           nbr_distance_cutoff_A=100,
                           dtype=np.float32)

    def run_consistency_check(self):
        N, F, S = self.get_N_F_S()
        print(N, F, S)
        assert N == 30
        assert F == 46
        assert S == 28

        try:
            from pyrosetta import pose_from_sequence
            from menten_gcn import RosettaPoseWrapper

            pose = pose_from_sequence("MENTENAI")
            wrapped_pose = RosettaPoseWrapper(pose)
            X, A, E, meta = self.generate_input_for_resid(wrapped_pose, 1)

            def test(A, B):
                np.testing.assert_array_equal(A, B, 3)

            '''
            import sys
            np.set_printoptions(threshold=sys.maxsize)
            print( repr( X ) )
            print( repr( A ) )
            print( repr( E ) )
            print( repr( meta ) )
            '''
            test(meta, [1, 2, 3, 4, 5, 6, 7, 8])

            expected_X = np.array([[1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 1.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, 8.3775802e-07,
                                    1.0000000e+00, 5.2359877e-07, 1.0000000e+00, -5.7595867e-07,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 1.8672367e+03, 9.1478378e-01,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 3.2645603e+01, 0.0000000e+00, 0.0000000e+00,
                                    1.6573499e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, -2.2689281e-07,
                                    1.0000000e+00, -5.2359876e-08, 1.0000000e+00, -1.3962634e-07,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 5.3682019e+02, 2.2368712e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 3.9272125e+01, 1.9425745e+00, 0.0000000e+00,
                                    -2.7245300e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, 6.6141240e-16,
                                    1.0000000e+00, -1.2602073e-15, 1.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 1.0468760e+01, 3.8885200e-01,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 2.6608192e+01, 6.7491651e-01, 0.0000000e+00,
                                    -1.3402600e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 1.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, -1.3439035e-06,
                                    1.0000000e+00, 5.9341193e-07, 1.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 2.5641568e+00, 4.0509410e-02,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 5.9773567e+01, 1.7684269e+00, 0.0000000e+00,
                                    1.1517500e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, -2.2689281e-07,
                                    1.0000000e+00, -5.2359876e-08, 1.0000000e+00, -1.3962634e-07,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 5.3682019e+02, 2.2368712e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 3.9272125e+01, 1.9425745e+00, 0.0000000e+00,
                                    -2.7245300e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, -2.7057779e-16,
                                    1.0000000e+00, 3.2313005e-16, 1.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 1.0468760e+01, 3.8885200e-01,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 3.4736256e+01, 6.7491651e-01, 0.0000000e+00,
                                    -1.3402600e+00, 0.0000000e+00],
                                   [0.0000000e+00, 1.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 2.5678021e-01, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    2.6757073e-01, 0.0000000e+00, 7.2029513e-01, 0.0000000e+00,
                                    1.3246800e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    1.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 3.1415927e+00, 3.1415927e+00, 1.9198622e-07,
                                    1.0000000e+00, 1.1344640e-06, 1.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 2.9560727e+02, 3.5983735e-01,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 6.2573467e+01, 0.0000000e+00, 0.0000000e+00,
                                    2.3037400e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00],
                                   [0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00, 0.0000000e+00, 0.0000000e+00,
                                    0.0000000e+00, 0.0000000e+00]], dtype=np.float32)

            expected_E = np.array([[np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209351e+00, 4.73696232e+00,
                                     2.55590057e+00, 1.94406962e+00, 3.78623873e-01, 0, 2.52958393e+00, 2.83850670e+00,
                                     1.11976581e-17, 3.14159274e+00, 2.22044605e-16,
                                     1.10479271e+00, 0, 0, 0, 0, 0,
                                     -4.57205915e+00, 8.80855896e+02, 7.82728672e+00,
                                     3.35431993e-01, -1.00192909e+01, 0, 0, 0, 0, 0],
                                    [0, 7.28560734e+00, 7.28560686e+00,
                                     1.16697186e-06, 2.57872105e+00, 9.72977459e-01,
                                     6.93147182e-01, 6.20201683e+00, 3.82296467e+00,
                                     6.42421180e-16, -5.30027373e-16, -2.22044605e-16,
                                     -1.79768915e-06, 0, 0, 0, 0, 0,
                                     -1.92229003e-01, 0, 2.19786674e-01,
                                     -5.78640960e-02, -3.56009841e-01, 0, 0, 0, 0, 0],
                                    [0, 1.09825363e+01, 1.13401499e+01,
                                     3.00454664e+00, 2.43993378e+00, 7.23135471e-01,
                                     1.09861231e+00, 8.73160267e+00, 6.66147280e+00,
                                     -2.44219418e-17, 3.14159274e+00, 4.44089210e-16,
                                     1.10479355e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.45712175e+01, 1.45712175e+01,
                                     9.06385296e-08, 2.57872105e+00, 9.72977459e-01,
                                     1.38629436e+00, 1.24040346e+01, 7.64593363e+00,
                                     1.28483897e-15, -1.06005580e-15, -6.66133815e-16,
                                     -1.39626337e-07, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [[1.00000000e+00, 3.80209351e+00, 4.73696232e+00,
                                     2.55590057e+00, -3.41464520e-01, 1.50724781e+00, 0, -3.67243147e+00, -9.84460473e-01,
                                     4.68176749e-17, -3.14159274e+00, -2.22044605e-16,
                                     1.10479271e+00, 0, 0, 0, 0, 0,
                                     -4.57205915e+00, 8.80855896e+02, 7.82728672e+00,
                                     3.35431993e-01, -1.00192909e+01, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209446e+00, 4.73696232e+00,
                                       2.55590081e+00, 1.94406879e+00, 3.78623903e-01, 0, 2.52958250e+00, 2.83850908e+00,
                                       1.11970799e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479450e+00, 0, 0, 0, 0, 0,
                                       -2.22846270e+00, 2.04876663e+02, 2.69857574e+00,
                                       -1.21587858e-01, -1.10309076e+00, 0, 0, 0, 0, 0],
                                    [0, 7.28560972e+00, 7.28560925e+00,
                                       5.55161478e-07, 2.57872009e+00, 9.72977221e-01,
                                       6.93147182e-01, 6.20201588e+00, 3.82297087e+00,
                                       6.42420386e-16, -5.30027532e-16, -2.22044605e-16,
                                       -8.55211340e-07, 0, 0, 0, 0, 0,
                                       -7.39678815e-02, 0, 1.09441765e-01,
                                       -1.31108221e-02, 1.17330207e-02, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454545e+00, 2.43993306e+00, 7.23135352e-01,
                                       1.09861231e+00, 8.73160076e+00, 6.66147757e+00,
                                       -2.44209194e-17, 3.14159274e+00, 4.44089210e-16,
                                       1.10479283e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.45712175e+01, 1.45712166e+01,
                                       1.07633355e-06, 2.57872057e+00, 9.72977340e-01,
                                       1.38629436e+00, 1.24040337e+01, 7.64593601e+00,
                                       1.28484437e-15, -1.06005464e-15, -6.66133815e-16,
                                       -1.65806284e-06, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [[0, 7.28560734e+00, 7.28560686e+00,
                                     1.16697186e-06, -5.62873721e-01, 2.16861582e+00,
                                     6.93147182e-01, -6.20201015e+00, -3.82297587e+00,
                                     -6.42420810e-16, 5.30027955e-16, 4.44089210e-16,
                                     1.79768915e-06, 0, 0, 0, 0, 0,
                                     -1.92229003e-01, 0, 2.19786674e-01,
                                     -5.78640960e-02, -3.56009841e-01, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209446e+00, 4.73696232e+00,
                                       2.55590081e+00, -3.41465622e-01, 1.50724840e+00, 0, -3.67243123e+00, -9.84464645e-01,
                                       4.68172051e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479450e+00, 0, 0, 0, 0, 0,
                                       -2.22846270e+00, 2.04876663e+02, 2.69857574e+00,
                                       -1.21587858e-01, -1.10309076e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209589e+00, 4.73696327e+00,
                                       2.55589986e+00, 1.94406736e+00, 3.78624082e-01, 0, 2.52958083e+00, 2.83851242e+00,
                                       1.11972230e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479534e+00, 0, 0, 0, 0, 0,
                                       -1.31169045e+00, 6.74720097e+00, 1.67359757e+00,
                                       1.66524708e-01, 1.47069490e+00, 0, 0, 0, 0, 0],
                                    [0, 7.28561020e+00, 7.28561068e+00,
                                       -1.07633332e-06, 2.57871890e+00, 9.72976923e-01,
                                       6.93147182e-01, 6.20201063e+00, 3.82297993e+00,
                                       6.42419380e-16, -5.30027955e-16, -2.22044605e-16,
                                       1.65806284e-06, 0, 0, 0, 0, 0,
                                       -6.20821118e-01, 0, 8.71631145e-01,
                                       1.06285838e-03, -7.25033402e-01, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454521e+00, 2.43993092e+00, 7.23134995e-01,
                                       1.09861231e+00, 8.73158836e+00, 6.66149330e+00,
                                       -2.44247823e-17, 3.14159274e+00, 4.44089210e-16,
                                       1.10479617e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.45712204e+01, 1.45712204e+01,
                                       -8.27077542e-07, 2.57871866e+00, 9.72976804e-01,
                                       1.38629436e+00, 1.24040203e+01, 7.64596176e+00,
                                       1.28483802e-15, -1.06005549e-15, -6.66133815e-16,
                                       1.27409032e-06, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [[0, 1.09825363e+01, 1.13401499e+01,
                                     3.00454664e+00, -4.65556115e-01, 1.91248298e+00,
                                     1.09861231e+00, -9.87444305e+00, -4.80743980e+00,
                                     8.24374220e-17, -3.14159274e+00, -4.44089210e-16,
                                     1.10479355e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 7.28560972e+00, 7.28560925e+00,
                                       5.55161478e-07, -5.62873423e-01, 2.16861558e+00,
                                       6.93147182e-01, -6.20201254e+00, -3.82297611e+00,
                                       -6.42420704e-16, 5.30027796e-16, 4.44089210e-16,
                                       8.55211340e-07, 0, 0, 0, 0, 0,
                                       -7.39678815e-02, 0, 1.09441765e-01,
                                       -1.31108221e-02, 1.17330207e-02, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209589e+00, 4.73696327e+00,
                                       2.55589986e+00, -3.41465712e-01, 1.50724864e+00, 0, -3.67243266e+00, -9.84464884e-01,
                                       4.68171190e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479534e+00, 0, 0, 0, 0, 0,
                                       -1.31169045e+00, 6.74720097e+00, 1.67359757e+00,
                                       1.66524708e-01, 1.47069490e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209374e+00, 4.73696232e+00,
                                       2.55589986e+00, 1.94406843e+00, 3.78623903e-01, 0, 2.52958202e+00, 2.83850884e+00,
                                       1.11975100e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479379e+00, 0, 0, 0, 0, 0,
                                       -3.67839885e+00, 8.79898254e+02, 6.06281567e+00,
                                       3.71687233e-01, -4.08100748e+00, 0, 0, 0, 0, 0],
                                    [0, 7.28560781e+00, 7.28560734e+00,
                                       5.21172012e-07, 2.57872009e+00, 9.72977221e-01,
                                       6.93147182e-01, 6.20201397e+00, 3.82297063e+00,
                                       6.42420863e-16, -5.30027426e-16, -2.22044605e-16,
                                       -8.02851446e-07, 0, 0, 0, 0, 0,
                                       -2.02662915e-01, 0, 2.20212236e-01,
                                       -5.84062114e-02, -3.69073659e-01, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454569e+00, 2.43993258e+00, 7.23135293e-01,
                                       1.09861231e+00, 8.73159790e+00, 6.66148043e+00,
                                       -2.44220195e-17, 3.14159274e+00, 4.44089210e-16,
                                       1.10479414e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.45712185e+01, 1.45712194e+01,
                                       -1.58617510e-07, 2.57872009e+00, 9.72977221e-01,
                                       1.38629436e+00, 1.24040298e+01, 7.64594460e+00,
                                       1.28483982e-15, -1.06005559e-15, -6.66133815e-16,
                                       2.44346097e-07, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [[0, 1.45712175e+01, 1.45712175e+01,
                                     9.06385296e-08, -5.62871814e-01, 2.16861534e+00,
                                     1.38629436e+00, -1.24040337e+01, -7.64593506e+00,
                                     -1.28483844e-15, 1.06005591e-15, 6.66133815e-16,
                                     1.39626337e-07, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454545e+00, -4.65554893e-01, 1.91248250e+00,
                                       1.09861231e+00, -9.87444973e+00, -4.80742836e+00,
                                       8.24393609e-17, -3.14159274e+00, -4.44089210e-16,
                                       1.10479283e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 7.28561020e+00, 7.28561068e+00,
                                       -1.07633332e-06, -5.62871873e-01, 2.16861534e+00,
                                       6.93147182e-01, -6.20201731e+00, -3.82296968e+00,
                                       -6.42419433e-16, 5.30027373e-16, 4.44089210e-16,
                                       -1.65806284e-06, 0, 0, 0, 0, 0,
                                       -6.20821118e-01, 0, 8.71631145e-01,
                                       1.06285838e-03, -7.25033402e-01, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209374e+00, 4.73696232e+00,
                                       2.55589986e+00, -3.41464877e-01, 1.50724792e+00, 0, -3.67243147e+00, -9.84461367e-01,
                                       4.68175161e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479379e+00, 0, 0, 0, 0, 0,
                                       -3.67839885e+00, 8.79898254e+02, 6.06281567e+00,
                                       3.71687233e-01, -4.08100748e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209446e+00, 4.73696232e+00,
                                       2.55590081e+00, 1.94406879e+00, 3.78623903e-01, 0, 2.52958250e+00, 2.83850908e+00,
                                       1.11970799e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479450e+00, 0, 0, 0, 0, 0,
                                       -2.22846270e+00, 2.04876663e+02, 2.69857574e+00,
                                       -1.21587858e-01, -1.10309076e+00, 0, 0, 0, 0, 0],
                                    [0, 7.28561020e+00, 7.28560972e+00,
                                       2.49256118e-07, 2.57872009e+00, 9.72977221e-01,
                                       6.93147182e-01, 6.20201588e+00, 3.82297158e+00,
                                       6.42420122e-16, -5.30027690e-16, -2.22044605e-16,
                                       -3.83972434e-07, 0, 0, 0, 0, 0,
                                       -6.45447522e-02, 0, 1.05444595e-01,
                                       -1.05051743e-02, -1.32832214e-01, 0, 0, 0, 0, 0],
                                    [0, 1.09825382e+01, 1.13401518e+01,
                                       3.00454569e+00, 2.43993282e+00, 7.23135352e-01,
                                       1.09861231e+00, 8.73160076e+00, 6.66147947e+00,
                                       -2.44219004e-17, 3.14159274e+00, 4.44089210e-16,
                                       1.10479343e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [np.zeros(shape=(S)),
                                    [0, 1.45712175e+01, 1.45712166e+01,
                                       1.07633355e-06, -5.62873960e-01, 2.16861582e+00,
                                       1.38629436e+00, -1.24040203e+01, -7.64595652e+00,
                                       -1.28484427e-15, 1.06005580e-15, 6.66133815e-16,
                                       1.65806284e-06, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454521e+00, -4.65556622e-01, 1.91248310e+00,
                                       1.09861231e+00, -9.87444305e+00, -4.80744314e+00,
                                       8.24356883e-17, -3.14159274e+00, -4.44089210e-16,
                                       1.10479617e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 7.28560781e+00, 7.28560734e+00,
                                       5.21172012e-07, -5.62873483e-01, 2.16861558e+00,
                                       6.93147182e-01, -6.20201111e+00, -3.82297564e+00,
                                       -6.42420492e-16, 5.30027690e-16, 4.44089210e-16,
                                       8.02851446e-07, 0, 0, 0, 0, 0,
                                       -2.02662915e-01, 0, 2.20212236e-01,
                                       -5.84062114e-02, -3.69073659e-01, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209446e+00, 4.73696232e+00,
                                       2.55590081e+00, -3.41465622e-01, 1.50724840e+00, 0, -3.67243123e+00, -9.84464645e-01,
                                       4.68172051e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479450e+00, 0, 0, 0, 0, 0,
                                       -2.22846270e+00, 2.04876663e+02, 2.69857574e+00,
                                       -1.21587858e-01, -1.10309076e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209589e+00, 4.73696375e+00,
                                       2.55589986e+00, 1.94406760e+00, 3.78624111e-01, 0, 2.52958155e+00, 2.83851218e+00,
                                       1.11973512e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479486e+00, 0, 0, 0, 0, 0,
                                       -7.31544256e-01, 1.80469227e+00, 3.98014307e-01,
                                       -1.71806701e-02, -2.58314610e-01, 0, 0, 0, 0, 0],
                                    [0, 7.28561115e+00, 7.28561163e+00,
                                       -6.79789594e-07, 2.57871914e+00, 9.72976923e-01,
                                       6.93147182e-01, 6.20201254e+00, 3.82297897e+00,
                                       6.42419963e-16, -5.30027796e-16, -2.22044605e-16,
                                       1.04719754e-06, 0, 0, 0, 0, 0,
                                       -4.29591179e-01, 0, -7.36617744e-02,
                                       -4.40440699e-02, -9.07294303e-02, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    [0, 1.45712204e+01, 1.45712204e+01,
                                       -8.27077542e-07, -5.62872589e-01, 2.16861534e+00,
                                       1.38629436e+00, -1.24040298e+01, -7.64594603e+00,
                                       -1.28483876e-15, 1.06005464e-15, 6.66133815e-16,
                                       -1.27409032e-06, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.09825373e+01, 1.13401508e+01,
                                       3.00454569e+00, -4.65555817e-01, 1.91248286e+00,
                                       1.09861231e+00, -9.87444592e+00, -4.80743694e+00,
                                       8.24373029e-17, -3.14159274e+00, -4.44089210e-16,
                                       1.10479414e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 7.28561020e+00, 7.28560972e+00,
                                       2.49256118e-07, -5.62872946e-01, 2.16861558e+00,
                                       6.93147182e-01, -6.20201445e+00, -3.82297397e+00,
                                       -6.42420439e-16, 5.30027796e-16, 4.44089210e-16,
                                       3.83972434e-07, 0, 0, 0, 0, 0,
                                       -6.45447522e-02, 0, 1.05444595e-01,
                                       -1.05051743e-02, -1.32832214e-01, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209589e+00, 4.73696375e+00,
                                       2.55589986e+00, -3.41465414e-01, 1.50724852e+00, 0, -3.67243314e+00, -9.84463811e-01,
                                       4.68172481e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479486e+00, 0, 0, 0, 0, 0,
                                       -7.31544256e-01, 1.80469227e+00, 3.98014307e-01,
                                       -1.71806701e-02, -2.58314610e-01, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)),
                                    [1.00000000e+00, 3.80209470e+00, 4.73696280e+00,
                                       2.55590081e+00, 1.94406915e+00, 3.78623962e-01, 0, 2.52958345e+00, 2.83850884e+00,
                                       1.11972619e-17, 3.14159274e+00, 2.22044605e-16,
                                       1.10479391e+00, 0, 0, 0, 0, 0,
                                       -2.75101089e+00, 7.84158997e+02, 4.00388569e-01,
                                       2.45321058e-02, -1.18683946e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   [np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    [0, 1.45712185e+01, 1.45712194e+01,
                                       -1.58617510e-07, -5.62872350e-01, 2.16861534e+00,
                                       1.38629436e+00, -1.24040318e+01, -7.64594173e+00,
                                       -1.28483844e-15, 1.06005538e-15, 6.66133815e-16,
                                       -2.44346097e-07, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 1.09825382e+01, 1.13401518e+01,
                                       3.00454569e+00, -4.65555400e-01, 1.91248274e+00,
                                       1.09861231e+00, -9.87444878e+00, -4.80743361e+00,
                                       8.24388779e-17, -3.14159274e+00, -4.44089210e-16,
                                       1.10479343e+00, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
                                    [0, 7.28561115e+00, 7.28561163e+00,
                                       -6.79789594e-07, -5.62872410e-01, 2.16861534e+00,
                                       6.93147182e-01, -6.20201635e+00, -3.82297254e+00,
                                       -6.42419645e-16, 5.30027426e-16, 4.44089210e-16,
                                       -1.04719754e-06, 0, 0, 0, 0, 0,
                                       -4.29591179e-01, 0, -7.36617744e-02,
                                       -4.40440699e-02, -9.07294303e-02, 0, 0, 0, 0, 0],
                                    [1.00000000e+00, 3.80209470e+00, 4.73696280e+00,
                                       2.55590081e+00, -3.41465175e-01, 1.50724828e+00, 0, -3.67243195e+00, -9.84463096e-01,
                                       4.68173837e-17, -3.14159274e+00, -2.22044605e-16,
                                       1.10479391e+00, 0, 0, 0, 0, 0,
                                       -2.75101089e+00, 7.84158997e+02, 4.00388569e-01,
                                       2.45321058e-02, -1.18683946e+00, 0, 0, 0, 0, 0],
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S)), np.zeros(shape=(S)),
                                    np.zeros(shape=(S))],

                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S)),
                                   np.zeros(shape=(N, S)), np.zeros(shape=(N, S))], dtype=np.float32)

            expected_A = np.array([[0., 1., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [1., 0., 1., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [1., 1., 0., 1., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [1., 1., 1., 0., 1., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [1., 1., 1., 1., 0., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 1., 1., 1., 1., 0., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 1., 1., 1., 1., 0., 1., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 1., 1., 1., 1., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.],
                                   [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
                                    0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.]],
                                  dtype=np.float32)

            test(X, expected_X)
            test(A, expected_A)
            test(E, expected_E)
        except ImportError:
            print("Unable to use pyrosetta. Did you call init?")
